ACFTestResultBoot

Notedocblock
ACFTestResultBoot

Result of the bootstrap test based on the classical autocorrelation function test_acf_bootstrap.

Fields:

  • stat::Float64: value of the test statistic.
  • boot_crit::Float64: bootstrap critical value.
  • boot_pval::Float64: bootstrap p-value.
  • boot_reject::Bool: whether the null hypothesis is rejected at the chosen level.
  • n_boot::Int: number of bootstrap replications.
  • boot_dist::Vector{Float64}: the n_boot resampled statistics (bootstrap null distribution). With Makie loaded, plot(res) draws it as a histogram.