OPTestResultBoot
Notedocblock
OPTestResultBootResult of the bootstrap ordinal-pattern test test_op_bootstrap.
Fields:
chart: the chart choice the test was computed for.stat::Float64: value of the test statistic.boot_crit::Float64: bootstrap critical value.boot_pval::Float64: bootstrap p-value.boot_reject::Bool: whether the null hypothesis is rejected at the chosen level.n_boot::Int: number of bootstrap replications.boot_dist::Vector{Float64}: then_bootresampled statistics, i.e. the bootstrap null distribution the critical value and the p-value were computed from. With Makie loaded,plot(res)draws a histogram ofboot_distwith the rejection region, the critical value and the observed statistic; see the plotting tutorial in the docs.