SACFBPTestResultBoot
Notedocblock
SACFBPTestResultBootResult of the bootstrap Box-Pierce type test based on the spatial autocorrelation function test_sacf_bp_bootstrap.
Fields:
stat::Float64: value of the test statistic.boot_crit::Float64: bootstrap critical value.boot_pval::Float64: bootstrap p-value.boot_reject::Bool: whether the null hypothesis is rejected at the chosen level.n_boot::Int: number of bootstrap replications.boot_dist::Vector{Float64}: then_bootresampled statistics (bootstrap null distribution). With Makie loaded,plot(res)draws it as a histogram.