SOPTestResult
Notedocblock
SOPTestResultResult of the asymptotic test based on spatial ordinal patterns test_sop.
Fields:
chart: the chart choice the test was computed for.stat::Float64: value of the test statistic.asymp_crit::Float64: asymptotic critical value.asymp_pval::Float64: asymptotic p-value.asymp_reject::Bool: whether the null hypothesis is rejected at the chosen level.