arl_sacf_ic
Notedocblock
arl_sacf_ic(sp_dgp, lam, cl, d1, d2, reps=10_000; rl_max=typemax(Int))Compute the in-control average run length (ARL) of the EWMA chart based on the spatial autocorrelation function (SACF) at lag (d1, d2) via simulation. The computation is multithreaded.
sp_dgp::ICSTS: in-control spatial data generating process.lam: smoothing parameter of the EWMA statistic.cl: control limit of the chart, typically obtained fromcl_sacf.d1::Int: row delay.d2::Int: column delay.reps=10_000: number of replications.rl_max::Int=typemax(Int): maximal run length after which a replication is stopped. Returns the tuple(ARL, standard error).