bootstrap_op
Notedocblock
bootstrap_op(data, n_boot; chart_choice, m=3, d=1, block_size=1)Compute the bootstrap distribution of the ordinal-pattern chart statistic for the time series data and return a vector of n_boot bootstrap statistics.
data::Vector{Float64}: the time series.n_boot::Int: number of bootstrap replications.chart_choice: one ofShannon(),ShannonExtropy(),DistanceToWhiteNoise(),UpDownBalance(),Persistence(),RotationalAsymmetry(),UpDownScaling(). ForShannonandShannonExtropy, the statistic is in the logarithm base of the chart, which must be larger than 1. Both default to base 2 in ComplexityMeasures.jl; useShannon(base=exp(1))for the natural logarithm used in the papers.m=3: length of the ordinal patterns.d=1: delay between observations of a pattern.block_size::Int=1: block length for the resampling.1corresponds to an i.i.d. bootstrap; values> 1yield a moving-block bootstrap that preserves serial dependence.