chart_stat_op

Notedocblock
chart_stat_op(p_vec, chart_choice)

Compute the (in-control) chart statistic of an ordinal-pattern distribution p_vec for the given chart choice.

The Shannon and Shannon-extropy statistics are computed in the logarithm base of chart_choice, which must be larger than 1. Note that Shannon() and ShannonExtropy() default to base 2 in ComplexityMeasures.jl; use Shannon(base=exp(1)) for the natural logarithm used in the papers. See the section on the logarithm base in the docs.