crit_val_sacf

Notedocblock
crit_val_sacf(M, N; alpha=0.05)

Return the asymptotic two sided critical value of the SACF statistic stat_sacf for an M × N image. The null hypothesis of no spatial dependence is rejected when the absolute value of the statistic exceeds it.

  • M::Int: number of rows of the data matrix.
  • N::Int: number of columns of the data matrix.
  • alpha=0.05: significance level.

Examples

# compute critical value
crit_val_sacf(11, 11)