crit_val_sop
Notedocblock
crit_val_sop(M, N, d1, d2; chart_choice, refinement=OrdinaryType(), alpha=0.05)Compute the critical value for the asymptotic test based on spatial ordinal patterns (SOPs); see test_sop.
M::Int: number of rows of the data matrix. The SOP matrix hasm = M - d1rows.N::Int: number of columns of the data matrix. The SOP matrix hasn = N - d2columns.d1::Int: row delay.d2::Int: column delay.chart_choice: one ofTauHat(),KappaHat(),TauTilde(),KappaTilde(),Shannon(),ShannonExtropy(),DistanceToWhiteNoise(). The critical value does not depend on the logarithm base ofShannonandShannonExtropy.refinement:OrdinaryType()for the classical SOP classification, or one ofRotationType(),DirectionType(),DiagonalType()(only for the entropy-type charts).alpha=0.05: significance level.
Examples
crit_val_sop(11, 11, 1, 1; chart_choice=TauHat())