stat_gop

Notedocblock
stat_gop(data, null_dist, chart_choice, m=3, d=1)
stat_gop(data, null_dist, lam, chart_choice, m=3, d=1)

Compute the chart statistic based on generalized ordinal patterns (GOPs) for the discrete-valued time series data. GOPs extend ordinal patterns by accounting for ties; see Weiß and Schnurr (2024).

The first method computes the statistic once for the whole series and returns a scalar. The second method additionally applies EWMA smoothing with parameter lam and returns the vector of sequentially computed chart statistics.

  • data: discrete-valued time series.
  • null_dist::DiscreteUnivariateDistribution: in-control (null) distribution, used to compute the in-control GOP distribution via fill_p0!.
  • lam::Float64: smoothing parameter of the EWMA statistic.
  • chart_choice: D_Chart() or Persistence().
  • m::Int=3: length of the ordinal patterns (currently only 3 is supported).
  • d=1: delay between observations of a pattern.