stat_op

Notedocblock
stat_op(data; chart_choice, m=3, d=1, add_noise=false)
stat_op(data, lam; chart_choice, m=3, d=1, add_noise=false)

Compute the ordinal-pattern chart statistic for the time series data. The ordinal patterns are indexed via the Lehmer code (see perm_to_lehm_idx!).

The first method computes the statistic once for the whole series and returns the vector [stat, p_rel], where stat is the chart statistic and p_rel the vector of relative ordinal-pattern frequencies.

The second method additionally applies EWMA smoothing with parameter lam (Equation (5) in Weiß and Testik (2023)) and returns the tuple (stats_all, p_rel), where stats_all contains the sequentially computed EWMA chart statistics.