stat_sacf
Notedocblock
stat_sacf(data, d1, d2)
stat_sacf(data, lam, d1, d2)Compute the spatial autocorrelation function (SACF) statistic at lag (d1, d2).
The first method takes a single image (matrix), centers it and returns the spatial autocorrelation as a Float64.
The second method takes a sequence of images (3-dimensional array, third dimension = time), applies EWMA smoothing with parameter lam and returns the vector of sequentially computed EWMA statistics, one per image.
data: data matrix (single image) or 3-dimensional array (image sequence).lam: smoothing parameter of the EWMA statistic (second method only).d1::Int: row delay.d2::Int: column delay. The asymptotic critical value is provided bycrit_val_sacf.