test_op

Notedocblock
test_op(ts; chart_choice, m=3, d=1, alpha=0.05)

Perform the asymptotic hypothesis test for serial dependence based on ordinal patterns and return an OPTestResult containing the test statistic, the asymptotic critical value, the p-value, and the reject decision.