test_op_bootstrap

Notedocblock
test_op_bootstrap(data, n_boot; chart_choice, m=3, d=1, alpha=0.05, block_size=1)

Compute a bootstrap hypothesis test for ordinal patterns and return an OPTestResultBoot with the bootstrap critical value, p-value, and reject decision.

Unlike test_op(), this function does not rely on asymptotic distributions and therefore works for any pattern length m, including m > 3 where no asymptotic theory is available.