test_op_bp_bootstrap

Notedocblock
test_op_bp_bootstrap(data, n_boot, w; chart_choice, m=3, alpha=0.05,
  ljung_box=false, block_size=1)

Compute a bootstrap Box-Pierce type hypothesis test for ordinal patterns and return an OPBPTestResultBoot with the bootstrap critical value, p-value, and reject decision.

Unlike test_op_bp, this does not rely on tabulated critical values and therefore works for any chart, any pattern length m, any maximal delay w and any significance level alpha.