test_sop

Notedocblock
test_sop(data, d1, d2; chart_choice, refinement=OrdinaryType(), alpha=0.05, add_noise=false)

Perform the asymptotic hypothesis test for spatial dependence based on spatial ordinal patterns (SOPs) and return a SOPTestResult with the test statistic, the asymptotic critical value, the p-value, and the reject decision.