test_sop_bootstrap

Notedocblock
test_sop_bootstrap(data, n_boot, d1, d2; chart_choice=TauTilde(),
  refinement=OrdinaryType(), alpha=0.05, block_size=1)

Compute a bootstrap hypothesis test for spatial ordinal patterns and return an SOPTestResultBoot with the bootstrap critical value, p-value, and reject decision.

For Tau/Kappa charts the raw statistic is used. For entropy charts (Shannon, ShannonExtropy, DistanceToWhiteNoise) the same rescale_sop transformation used by test_sop is applied so that the bootstrap critical value is on the same scale as the asymptotic critical value and the two can be compared directly.