ACFTestResult
Notedocblock
ACFTestResultResult of the asymptotic test based on the classical autocorrelation function test_acf.
Fields:
stat::Float64: value of the test statistic.asymp_crit::Float64: asymptotic critical value.asymp_pval::Float64: asymptotic p-value.asymp_reject::Bool: whether the null hypothesis is rejected at the chosen level.