chart_stat_op
Notedocblock
chart_stat_op(p_vec, chart_choice)Compute the (in-control) chart statistic of an ordinal-pattern distribution p_vec for the given chart choice.
p_vec: vector of (relative) ordinal-pattern frequencies of lengthm!, ordered by their Lehmer index (seeperm_to_lehm_idx).chart_choice: one ofShannon(),ShannonExtropy(),DistanceToWhiteNoise(),UpDownBalance(),Persistence(),RotationalAsymmetry(),UpDownScaling(). Returns the value of the chart statistic. The Shannon and Shannon-extropy statistics follow Equation (3) in Weiß and Testik (2023); the β-, τ-, γ- and δ-statistics follow Equations (3)–(6) in Bandt (2019) and requirem = 3(UpDownBalancealso supportsm = 2).
The Shannon and Shannon-extropy statistics are computed in the logarithm base of chart_choice, which must be larger than 1. Note that Shannon() and ShannonExtropy() default to base 2 in ComplexityMeasures.jl; use Shannon(base=exp(1)) for the natural logarithm used in the papers. See the section on the logarithm base in the docs.