test_op_bp_bootstrap
Notedocblock
test_op_bp_bootstrap(data, n_boot, w; chart_choice, m=3, alpha=0.05,
ljung_box=false, block_size=1)Compute a bootstrap Box-Pierce type hypothesis test for ordinal patterns and return an OPBPTestResultBoot with the bootstrap critical value, p-value, and reject decision.
Unlike test_op_bp, this does not rely on tabulated critical values and therefore works for any chart, any pattern length m, any maximal delay w and any significance level alpha.
data: the time series.n_boot: number of bootstrap replications.w: maximal delay; the individual statistics for delays1:ware aggregated.chart_choice: one ofShannon(),ShannonExtropy(),DistanceToWhiteNoise(),UpDownBalance(),Persistence(),RotationalAsymmetry(),UpDownScaling(). ForShannonandShannonExtropy, the logarithm base must be larger than 1. The statistic does not depend on it.m::Int=3: length of the ordinal patterns.alpha: significance level (default0.05).ljung_box::Bool=false: iftrue, use Ljung-Box (BL) weights.block_size: set> 1for a block bootstrap that preserves serial dependencies.