test_sacf_bp
Notedocblock
test_sacf_bp(data, w; alpha=0.05)Perform the asymptotic Box-Pierce type test for spatial dependence based on the spatial autocorrelation function (SACF), aggregating the squared SACF values over all delays up to w, and return a SACFBPTestResult with the test statistic, the asymptotic critical value, the p-value, and the reject decision.
data::Matrix{<:Real}: data matrix (spatial field).w::Int: window size; delays up towin each direction are used.alpha=0.05: significance level.